summaryrefslogtreecommitdiff
path: root/lib/omb.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/omb.php')
-rw-r--r--lib/omb.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/omb.php b/lib/omb.php
index 4f6a96095..7dca760c6 100644
--- a/lib/omb.php
+++ b/lib/omb.php
@@ -1,7 +1,7 @@
<?php
/*
* Laconica - a distributed open-source microblogging tool
* Copyright (C) 2008, 2009, Control Yourself, Inc.
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
@@ -17,7 +17,7 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-if (!defined('LACONICA')) { exit(1); }
+if (!defined('STATUSNET') && !defined('LACONICA')) { exit(1); }
require_once('OAuth.php');
require_once(INSTALLDIR.'/lib/oauthstore.php');
@@ -66,7 +66,7 @@ function omb_oauth_datastore()
{
static $store = null;
if (!$store) {
- $store = new LaconicaOAuthDataStore();
+ $store = new StatusNetOAuthDataStore();
}
return $store;
}
@@ -135,7 +135,7 @@ function omb_broadcast_remote_subscribers($notice)
$posted = array();
while ($rp->fetch()) {
- if (!$posted[$rp->postnoticeurl]) {
+ if (!array_key_exists($rp->postnoticeurl, $posted)) {
common_log(LOG_DEBUG, 'Posting to ' . $rp->postnoticeurl);
if (omb_post_notice_keys($notice, $rp->postnoticeurl, $rp->token, $rp->secret)) {
common_log(LOG_DEBUG, 'Finished to ' . $rp->postnoticeurl);
@@ -202,7 +202,7 @@ function omb_post_notice_keys($notice, $postnoticeurl, $tk, $secret)
$result = $fetcher->post($req->get_normalized_http_url(),
$req->to_postdata(),
- array('User-Agent: Laconica/' . LACONICA_VERSION));
+ array('User-Agent: StatusNet/' . STATUSNET_VERSION));
if ($result->status == 403) { # not authorized, don't send again
common_debug('403 result, deleting subscription', __FILE__);
@@ -282,7 +282,7 @@ function omb_update_profile($profile, $remote_profile, $subscription)
$result = $fetcher->post($req->get_normalized_http_url(),
$req->to_postdata(),
- array('User-Agent: Laconica/' . LACONICA_VERSION));
+ array('User-Agent: StatusNet/' . STATUSNET_VERSION));
if (empty($result) || !$result) {
common_debug("Unable to contact " . $req->get_normalized_http_url());
@@ -1,7 +1,7 @@
<?php
/*
- * Laconica - a distributed open-source microblogging tool
- * Copyright (C) 2008, 2009, Control Yourself, Inc.
+ * StatusNet - the distributed open-source microblogging tool
+ * Copyright (C) 2008, 2009, StatusNet, Inc.
*
* This program is free software: you can redistribute it and/or modify